
#ifndef _C13_co621_
#define _C13_co621_

#ifdef __cplusplus
extern "C" {
#endif

extern void F1302_11663(EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit621(void);

#ifdef __cplusplus
}
#endif

#endif
